@@ -3,11 +3,12 @@ from pathlib import Path
 from typing import List, Optional
 
 import darwin.datatypes as dt
+from darwin.path_utils import deconstruct_full_path
 
 
 def parse_file(path: Path) -> Optional[List[dt.AnnotationFile]]:
     if path.suffix != ".csv":
-        return
+        return None
 
     files = []
     with path.open() as f:
@@ -18,5 +19,6 @@ def parse_file(path: Path) -> Optional[List[dt.AnnotationFile]]:
                 continue
             annotations = [dt.make_tag(tag) for tag in tags if len(tag) > 0]
             annotation_classes = set([annotation.annotation_class for annotation in annotations])
-            files.append(dt.AnnotationFile(path, filename, annotation_classes, annotations, remote_path = "/"))
+            remote_path, filename = deconstruct_full_path(filename)
+            files.append(dt.AnnotationFile(path, filename, annotation_classes, annotations, remote_path=remote_path))
     return files
